@@ -55,7 +55,7 @@ def drop_db(config, dbname):
     conn = config.get_odoo_conn().clone(dbname='postgres')
     _remove_postgres_connections(
         conn, sql_afterwards=f"drop database {dbname};")
-    click.echo("Database {} dropped.".format(dbname))
+    click.echo(f"Database {dbname} dropped.")
 
 @db.command()
 @pass_config
@@ -90,14 +90,13 @@ def pgcli(config, dbname, params, host, port, user, password):
     from .tools import DBConnection
 
     dbname = dbname or config.dbname
-    os.environ['ODOO_FRAMEWORK_KEEP_SQL_CONNECTION'] = '1'  # will be executed there so connection string will point to postgres
 
     if host:
         if any(not x for x in [port, user, password]):
             click.secho("If you provide a host, then provide please all connection informations.")
         conn = DBConnection(dbname, host, int(port), user, password)
     else:
-        conn = config.get_odoo_conn().clone(dbname=dbname)
+        conn = config.get_odoo_conn(inside_container=True).clone(dbname=dbname)
     return _pgcli(config, conn, params, use_docker_container=True)
 
 @db.command()
@@ -108,8 +107,7 @@ def pgcli(config, dbname, params, host, port, user, password):
 @pass_config
 def psql(config, dbname, params, sql, non_interactive):
     dbname = dbname or config.dbname
-    os.environ['ODOO_FRAMEWORK_KEEP_SQL_CONNECTION'] = '1'  # will be executed there so connection string will point to postgres
-    conn = config.get_odoo_conn().clone(dbname=dbname)
+    conn = config.get_odoo_conn(inside_container=True).clone(dbname=dbname)
     return _psql(config, conn, params, sql=sql, interactive=not non_interactive)
 
 def _psql(config, conn, params, bin='psql', sql=None, use_docker_container=None, interactive=True):
@@ -119,7 +117,9 @@ def _psql(config, conn, params, bin='psql', sql=None, use_docker_container=None,
             dbname = params[0]
             params = []
     params = " ".join(params)
-    psql_args = ['-h', conn.host, '-p', str(conn.port), '-U', conn.user]
+    psql_args = ['-h', str(conn.host), '-U', conn.user]
+    if conn.port:
+        psql_args += ['-p', str(conn.port)]
     if bin == 'psql':
         psql_args += ['-v', 'ON_ERROR_STOP=1']
     if sql:
@@ -462,57 +462,125 @@ def excel(config, sql, file, base64):
 @pass_config
 def pghba_conf_wide_open(config, no_scram):
     conn = config.get_odoo_conn().clone(dbname='postgres')
-    setting = _execute_sql(
-        conn,
-        "select setting from pg_settings where name like '%hba%';",
-        fetchone=True)
 
-    if not setting:
-        click.secho("No pghba.conf location found.")
-        return
-    pghba_conf = setting[0]
+    def adapt_pghba_conf():
+        setting = _execute_sql(
+            conn,
+            "select setting from pg_settings where name like '%hba%';",
+            fetchone=True)
 
-    _execute_sql(
-        conn, "drop table if exists hba;"
-    )
-    _execute_sql(
-        conn, "create table hba ( lines text );"
-    )
+        if not setting:
+            click.secho("No pghba.conf location found.")
+            return
+        pghba_conf = setting[0]
 
-    _execute_sql(conn, f"copy hba from '{pghba_conf}';")
-    _execute_sql(
-        conn, (
-            "delete from hba "
-            "where lines like 'host%all%all%all%md5'"
-    ))
-    _execute_sql(
-        conn, (
-            "insert into hba (lines) "
-            "values ('"
-            f"host all all all md5"
-            "');"
-    ))
-    if no_scram:
+        _execute_sql(
+            conn, "drop table if exists hba;"
+        )
+        _execute_sql(
+            conn, "create table hba ( lines text );"
+        )
+
+        _execute_sql(conn, f"copy hba from '{pghba_conf}';")
         _execute_sql(
             conn, (
-                "update hba "
-                " set lines = replace(lines, 'scram-sha-256', 'md5')"
+                "delete from hba "
+                "where lines like 'host%all%all%all%md5'"
         ))
-    _execute_sql(conn, f"copy hba to '{pghba_conf}';")
-    _execute_sql(conn, "select pg_reload_conf();")
-    _execute_sql(conn, "drop table hba")
-    _execute_sql(
-        conn, "create table hba ( lines text );"
-    )
-    _execute_sql(conn, f"copy hba from '{pghba_conf}';")
+        for method in ['trust', 'scram', 'md5']:
+            _execute_sql(
+                conn, (
+                    "delete from hba "
+                    f"where lines like 'host%all%all%all%{method}'"
+            ))
+
+        def trustline():
+            if config.devmode:
+                trustline = "host all all all trust"
+            else:
+                if no_scram:
+                    trustline = "host all all all md5"
+                else:
+                    trustline = "host all all all scram-sha-256"
+            _execute_sql(
+                conn, (
+                    f"insert into hba(lines) values('{trustline}');"
+            ))
+        trustline()
+
+        _execute_sql(conn, f"copy hba to '{pghba_conf}';")
+        _execute_sql(conn, "select pg_reload_conf();")
+        _execute_sql(conn, "drop table hba")
+        _execute_sql(
+            conn, "create table hba ( lines text );"
+        )
+        _execute_sql(conn, f"copy hba from '{pghba_conf}';")
+
+        rows = _execute_sql(conn, (
+            "select * from hba;"
+        ), fetchall=True)
+        for x in rows:
+            if x[0].startswith("#"):
+                continue
+            print(x[0])
+
+    def adapt_postgres_conf():
+        setting = _execute_sql(
+            conn,
+            "select setting from pg_settings where name = 'config_file';",
+            fetchone=True)
+
+        if not setting:
+            click.secho("No postgresql.conf location found.")
+            return
+        conf = setting[0]
+
+        _execute_sql(
+            conn, "drop table if exists hba;"
+        )
+        _execute_sql(
+            conn, "create table hba ( lines text );"
+        )
+
+        _execute_sql(conn, f"copy hba from '{conf}' with (delimiter E'~');")
+        _execute_sql(
+            conn, (
+                "delete from hba "
+                "where lines like '%password_encryption%'"
+        ))
+        _execute_sql(conn, (
+            "update hba set lines = replace(lines, '\t', ' ')"
+        ))
+        if no_scram:
+            _execute_sql(
+                conn, (
+                    "insert into hba (lines) "
+                    "values ('"
+                    f"password_encryption=md5"
+                    "');"
+            ))
+        _execute_sql(conn, f"copy hba to '{conf}';")
+        _execute_sql(conn, "select pg_reload_conf();")
+        _execute_sql(conn, "drop table hba")
+        _execute_sql(
+            conn, "create table hba ( lines text );"
+        )
+        _execute_sql(conn, f"copy hba from '{conf}';")
+
+        rows = _execute_sql(conn, (
+            "select * from hba;"
+        ), fetchall=True)
+        for x in rows:
+            if x[0].startswith("#"):
+                continue
+            print(x[0])
+
+
+    adapt_pghba_conf()
+    adapt_postgres_conf()
+
 
-    rows = _execute_sql(conn, (
-        "select * from hba;"
-    ), fetchall=True)
-    for x in rows:
-        if x[0].startswith("#"):
-            continue
-        print(x[0])
 
 
 Commands.register(reset_db, 'reset-db')
+Commands.register(pghba_conf_wide_open, 'pghba_conf_wide_open')
